## 1.11.0.20260216 (2026-02-16)

[stubsabot] Bump pyperclip to 1.11.* ([#14745](https://github.com/python/typeshed/pull/14745))

## 1.9.0.20250801 (2025-08-01)

Split `tool.stubtest.platforms` metadata key ([#13746](https://github.com/python/typeshed/pull/13746))

Co-authored-by: Avasam <samuel.06@hotmail.com>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 1.9.0.20250218 (2025-02-18)

Add pyperclip stubs ([#13502](https://github.com/python/typeshed/pull/13502))

